@@ -25,6 +25,7 @@ import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
 
 from google.cloud.bigquery_data_exchange_v1beta1.types import dataexchange
+from google.cloud.location import locations_pb2  # type: ignore
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
 from google.protobuf import empty_pb2  # type: ignore
@@ -35,12 +36,13 @@ from .grpc import AnalyticsHubServiceGrpcTransport
 class AnalyticsHubServiceGrpcAsyncIOTransport(AnalyticsHubServiceTransport):
     """gRPC AsyncIO backend transport for AnalyticsHubService.
 
-    The AnalyticsHubService API facilitates data sharing within
-    and across organizations. It allows data providers to publish
-    Listings --- a discoverable and searchable SKU representing a
-    dataset. Data consumers can subscribe to Listings. Upon
-    subscription, AnalyticsHub provisions a "Linked Datasets"
-    surfacing the data in the consumer's project.
+    The ``AnalyticsHubService`` API facilitates data sharing within and
+    across organizations. It allows data providers to publish listings
+    that reference shared datasets. With Analytics Hub, users can
+    discover and search for listings that they have access to.
+    Subscribers can view and subscribe to listings. When you subscribe
+    to a listing, Analytics Hub creates a linked dataset in your
+    project.
 
     This class defines the same methods as the primary client, so the
     primary client can load the underlying transport implementation
@@ -111,6 +113,7 @@ class AnalyticsHubServiceGrpcAsyncIOTransport(AnalyticsHubServiceTransport):
         quota_project_id=None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
     ) -> None:
         """Instantiate the transport.
 
@@ -206,6 +209,7 @@ class AnalyticsHubServiceGrpcAsyncIOTransport(AnalyticsHubServiceTransport):
             quota_project_id=quota_project_id,
             client_info=client_info,
             always_use_jwt_access=always_use_jwt_access,
+            api_audience=api_audience,
         )
 
         if not self._grpc_channel:
@@ -247,7 +251,8 @@ class AnalyticsHubServiceGrpcAsyncIOTransport(AnalyticsHubServiceTransport):
     ]:
         r"""Return a callable for the list data exchanges method over gRPC.
 
-        Lists DataExchanges in a given project and location.
+        Lists all data exchanges in a given project and
+        location.
 
         Returns:
             Callable[[~.ListDataExchangesRequest],
@@ -276,7 +281,7 @@ class AnalyticsHubServiceGrpcAsyncIOTransport(AnalyticsHubServiceTransport):
     ]:
         r"""Return a callable for the list org data exchanges method over gRPC.
 
-        Lists DataExchanges from projects in a given
+        Lists all data exchanges from projects in a given
         organization and location.
 
         Returns:
@@ -305,7 +310,7 @@ class AnalyticsHubServiceGrpcAsyncIOTransport(AnalyticsHubServiceTransport):
     ]:
         r"""Return a callable for the get data exchange method over gRPC.
 
-        Gets details of a single DataExchange.
+        Gets the details of a data exchange.
 
         Returns:
             Callable[[~.GetDataExchangeRequest],
@@ -333,8 +338,7 @@ class AnalyticsHubServiceGrpcAsyncIOTransport(AnalyticsHubServiceTransport):
     ]:
         r"""Return a callable for the create data exchange method over gRPC.
 
-        Creates a new DataExchange in a given project and
-        location.
+        Creates a new data exchange.
 
         Returns:
             Callable[[~.CreateDataExchangeRequest],
@@ -362,7 +366,7 @@ class AnalyticsHubServiceGrpcAsyncIOTransport(AnalyticsHubServiceTransport):
     ]:
         r"""Return a callable for the update data exchange method over gRPC.
 
-        Updates the parameters of a single DataExchange.
+        Updates an existing data exchange.
 
         Returns:
             Callable[[~.UpdateDataExchangeRequest],
@@ -388,7 +392,7 @@ class AnalyticsHubServiceGrpcAsyncIOTransport(AnalyticsHubServiceTransport):
     ) -> Callable[[dataexchange.DeleteDataExchangeRequest], Awaitable[empty_pb2.Empty]]:
         r"""Return a callable for the delete data exchange method over gRPC.
 
-        Deletes a single DataExchange.
+        Deletes an existing data exchange.
 
         Returns:
             Callable[[~.DeleteDataExchangeRequest],
@@ -416,7 +420,7 @@ class AnalyticsHubServiceGrpcAsyncIOTransport(AnalyticsHubServiceTransport):
     ]:
         r"""Return a callable for the list listings method over gRPC.
 
-        Lists Listings in a given project and location.
+        Lists all listings in a given project and location.
 
         Returns:
             Callable[[~.ListListingsRequest],
@@ -442,7 +446,7 @@ class AnalyticsHubServiceGrpcAsyncIOTransport(AnalyticsHubServiceTransport):
     ) -> Callable[[dataexchange.GetListingRequest], Awaitable[dataexchange.Listing]]:
         r"""Return a callable for the get listing method over gRPC.
 
-        Gets details of a single Listing.
+        Gets the details of a listing.
 
         Returns:
             Callable[[~.GetListingRequest],
@@ -468,8 +472,7 @@ class AnalyticsHubServiceGrpcAsyncIOTransport(AnalyticsHubServiceTransport):
     ) -> Callable[[dataexchange.CreateListingRequest], Awaitable[dataexchange.Listing]]:
         r"""Return a callable for the create listing method over gRPC.
 
-        Creates a new Listing in a given project and
-        location.
+        Creates a new listing.
 
         Returns:
             Callable[[~.CreateListingRequest],
@@ -495,7 +498,7 @@ class AnalyticsHubServiceGrpcAsyncIOTransport(AnalyticsHubServiceTransport):
     ) -> Callable[[dataexchange.UpdateListingRequest], Awaitable[dataexchange.Listing]]:
         r"""Return a callable for the update listing method over gRPC.
 
-        Updates the parameters of a single Listing.
+        Updates an existing listing.
 
         Returns:
             Callable[[~.UpdateListingRequest],
@@ -521,9 +524,7 @@ class AnalyticsHubServiceGrpcAsyncIOTransport(AnalyticsHubServiceTransport):
     ) -> Callable[[dataexchange.DeleteListingRequest], Awaitable[empty_pb2.Empty]]:
         r"""Return a callable for the delete listing method over gRPC.
 
-        Deletes a single Listing, as long as there are no
-        subscriptions associated with the source of this
-        Listing.
+        Deletes a listing.
 
         Returns:
             Callable[[~.DeleteListingRequest],
@@ -552,11 +553,12 @@ class AnalyticsHubServiceGrpcAsyncIOTransport(AnalyticsHubServiceTransport):
     ]:
         r"""Return a callable for the subscribe listing method over gRPC.
 
-        Subscribes to a single Listing.
-        Data Exchange currently supports one type of Listing: a
-        BigQuery dataset. Upon subscription to a Listing for a
-        BigQuery dataset, Data Exchange creates a linked dataset
-        in the subscriber's project.
+        Subscribes to a listing.
+        Currently, with Analytics Hub, you can create listings
+        that reference only BigQuery datasets.
+        Upon subscription to a listing for a BigQuery dataset,
+        Analytics Hub creates a linked dataset in the
+        subscriber's project.
 
         Returns:
             Callable[[~.SubscribeListingRequest],
@@ -582,7 +584,7 @@ class AnalyticsHubServiceGrpcAsyncIOTransport(AnalyticsHubServiceTransport):
     ) -> Callable[[iam_policy_pb2.GetIamPolicyRequest], Awaitable[policy_pb2.Policy]]:
         r"""Return a callable for the get iam policy method over gRPC.
 
-        Gets the IAM policy for a dataExchange or a listing.
+        Gets the IAM policy.
 
         Returns:
             Callable[[~.GetIamPolicyRequest],
@@ -608,7 +610,7 @@ class AnalyticsHubServiceGrpcAsyncIOTransport(AnalyticsHubServiceTransport):
     ) -> Callable[[iam_policy_pb2.SetIamPolicyRequest], Awaitable[policy_pb2.Policy]]:
         r"""Return a callable for the set iam policy method over gRPC.
 
-        Sets the IAM policy for a dataExchange or a listing.
+        Sets the IAM policy.
 
         Returns:
             Callable[[~.SetIamPolicyRequest],
@@ -637,8 +639,7 @@ class AnalyticsHubServiceGrpcAsyncIOTransport(AnalyticsHubServiceTransport):
     ]:
         r"""Return a callable for the test iam permissions method over gRPC.
 
-        Returns the permissions that a caller has on a
-        specified dataExchange or listing.
+        Returns the permissions that a caller has.
 
         Returns:
             Callable[[~.TestIamPermissionsRequest],
@@ -661,5 +662,41 @@ class AnalyticsHubServiceGrpcAsyncIOTransport(AnalyticsHubServiceTransport):
     def close(self):
         return self.grpc_channel.close()
 
+    @property
+    def list_locations(
+        self,
+    ) -> Callable[
+        [locations_pb2.ListLocationsRequest], locations_pb2.ListLocationsResponse
+    ]:
+        r"""Return a callable for the list locations method over gRPC."""
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "list_locations" not in self._stubs:
+            self._stubs["list_locations"] = self.grpc_channel.unary_unary(
+                "/google.cloud.location.Locations/ListLocations",
+                request_serializer=locations_pb2.ListLocationsRequest.SerializeToString,
+                response_deserializer=locations_pb2.ListLocationsResponse.FromString,
+            )
+        return self._stubs["list_locations"]
+
+    @property
+    def get_location(
+        self,
+    ) -> Callable[[locations_pb2.GetLocationRequest], locations_pb2.Location]:
+        r"""Return a callable for the list locations method over gRPC."""
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "get_location" not in self._stubs:
+            self._stubs["get_location"] = self.grpc_channel.unary_unary(
+                "/google.cloud.location.Locations/GetLocation",
+                request_serializer=locations_pb2.GetLocationRequest.SerializeToString,
+                response_deserializer=locations_pb2.Location.FromString,
+            )
+        return self._stubs["get_location"]
+
 
 __all__ = ("AnalyticsHubServiceGrpcAsyncIOTransport",)
